@@ -106,7 +106,7 @@ CATEGORIES = {
     ),
     "Label": Category(
         name="Label",
-        description="Turn images or binary images into\nlabel images by labeling objects.",
+        description="Turn images into label images by labeling objects.",
         inputs=(LayerInput,),
         default_op="voronoi_otsu_labeling (clesperanto)",
         output="labels",
@@ -160,17 +160,6 @@ CATEGORIES = {
         blending="translucent",
         tools_menu="Measurement",
     ),
-    "Mesh": Category(
-        name="Mesh",
-        description="Draw connectivity meshes between\ncentroids of labeled objects.",
-        inputs=(LabelsInput,),
-        default_op="draw_mesh_between_touching_labels (clesperanto)",
-        default_values=[1],
-        include=("label measurement", "mesh"),
-        color_map="green",
-        blending="additive",
-        tools_menu="Visualization",
-    ),
     "Label neighbor filters": Category(
         name="Label neighbor filters",
         description="Process values associated with labeled objects\naccording to the neighborhood-graph of the labels.",
@@ -182,6 +171,28 @@ CATEGORIES = {
         blending="translucent",
         tools_menu="Label neighbor filters",
     ),
+    "Label filters": Category(
+        name="Label filters",
+        description="Process label images depending on values in corresponding images.\nPleease use parametric maps only as input image.",
+        inputs=(ImageInput, LabelsInput),
+        default_op="exclude_labels_with_map_values_out_of_range (clesperanto)",
+        default_values=[1, 100],
+        include=('label processing', 'combine'),
+        exclude=("neighbor",),
+        tools_menu="Label filters",
+    ),
+    "Mesh": Category(
+        name="Mesh",
+        description="Draw connectivity meshes between\ncentroids of labeled objects.",
+        inputs=(LabelsInput,),
+        default_op="draw_mesh_between_touching_labels (clesperanto)",
+        default_values=[1],
+        include=("label measurement", "mesh"),
+        color_map="green",
+        blending="additive",
+        tools_menu="Visualization",
+    ),
+
 }
 
 
