@@ -322,18 +322,17 @@ def make_gui_for_category(category: Category, search_string:str = None, viewer:
         op_name = kwargs.pop("op_name")
         try:
             result, used_args = call_op(op_name, inputs, t_position, viewer, **kwargs)
-        except TypeError:
+        except TypeError as e:
             result = None
             used_args = []
             import warnings
-            warnings.warn("Operation failed. Please check input parameters and documentation.")
+            warnings.warn("Operation failed. Please check input parameters and documentation.\n" + str(e))
 
         # add a help-button
         description = find_function(op_name).__doc__
         if description is not None:
-            description = description.replace("\n    ", "\n") + "\n\nRight-click to learn more..."
-            temp = description.split('https:')
-            getattr(widget, OP_NAME_PARAM).native.setToolTip(description)
+            description = description.replace("\n    ", "\n").replace("\n", "<br/>")
+            getattr(widget, OP_NAME_PARAM).native.setToolTip("<html>" + description + "</html>")
 
         if result is not None:
             from napari.layers._source import layer_source
